Struct DirDiskUsage

pub struct DirDiskUsage {
    pub path: PathBuf,
    pub file_bytes: u64,
    pub shared_files: Vec<InodeKey>,
    pub subdirs: Vec<Result<DirDiskUsage>>,
    pub errors: Vec<ItemError>,
}
Disk usage of the contents of a particular directory

Fields

path: PathBuf

Path to this directory

file_bytes: u64

Files directly inside this directory, including subdirectories themselves (excluding their contents)

shared_files: Vec<InodeKey>

Files with a link count > 1 are recorded here, and added after finishing the scan, when the actual share count is known, so that their disk usage can be split across the usage sites

subdirs: Vec<Result<DirDiskUsage>>

Reflecting the contents of subdirectories

errors: Vec<ItemError>

Errors while processing the items directly inside this directory (errors processing subdirectories are kept in subdirs instead)

Implementations

Source

impl DirDiskUsage

pub fn total_files(&self, shared_inodes: &HashMap<InodeKey, InodeData>) -> u64

in bytes

pub fn total_subdirs(&self, shared_inodes: &HashMap<InodeKey, InodeData>) -> u64

in bytes

pub fn total(&self, shared_inodes: &HashMap<InodeKey, InodeData>) -> u64

total in bytes

pub fn get_errors(&self, limit: usize, out: &mut Vec<String>)

Collect all errors (of all kinds) of this tree into out