Struct InodeData

pub struct InodeData {
    pub bytes: u64,
    pub share_count: u64,
}

Fields

bytes: u64

The usual blocks * blocksize of the inode’s storage (as per stat)

share_count: u64

This is not the inode count (number of times an inode is used in the file system), but only the number of times this inode is seen in the file system tree we’re looking at. This is used when share_globally is not true.

Implementations

Source

impl InodeData

pub fn bytes_share_rounded(&self) -> u64

The number of bytes to consider for each usage site