pub struct DirDiskUsage {
pub path: PathBuf,
pub file_bytes: u64,
pub shared_files: Vec<InodeKey>,
pub subdirs: Vec<Result<DirDiskUsage>>,
pub errors: Vec<ItemError>,
}Expand description
Disk usage of the contents of a particular directory
Fields
path: PathBufPath to this directory
file_bytes: u64Files directly inside this directory, including subdirectories themselves (excluding their contents)
Files with a link count > 1 are recorded here, and added after finishing the scan, when the actual share count is known, so that their disk usage can be split across the usage sites
subdirs: Vec<Result<DirDiskUsage>>Reflecting the contents of subdirectories
errors: Vec<ItemError>Errors while processing the items directly inside this
directory (errors processing subdirectories are kept in
subdirs instead)
Implementations
Sourceimpl DirDiskUsage
impl DirDiskUsage
Sourcepub fn get_errors(&self, limit: usize, out: &mut Vec<String>)
pub fn get_errors(&self, limit: usize, out: &mut Vec<String>)
Collect all errors (of all kinds) of this tree into out